@@ -21,7 +21,7 @@
 extern gchar *command_file;
 extern gchar *progname;
 extern gchar *driver;
-extern msa_module *driver_module;
+extern struct msa_module *driver_module;
 extern gchar *log_file;
 extern FILE *stdlog;
 
